
// filter out all the ages under 21
const a = `
    filter @.attributes.age > 21;
`

// get the sum of the ages
const b = `
    reduce $.accumulator + $.current.attributes.age, 0;
`

// filter out all the ages under 21 and get the sum of the ages
const c = `
    filter @.attributes.age > 21;
    reduce $.accumulator + $.current.attributes.age, 0;
`

// filter out all the people with the name 'John'
const d = `
    filter @.attributes.name !== 'John';
`

// get the average of the ages
const f = `
    reduce aggregate($.accumulator, $.current.attributes.age), {};
    map processBin(@).average;
`

// filter for only payments with the type eCheck and get the sum of the amounts
const e = `
    filter @.attributes.type === 'eCheck';
    reduce $.accumulator + $.current.attributes.amount, 0;
`

// filter for only payments with the type 'Credit Card' and get the average of the amounts
const g = `
    filter @.attributes.type === 'Credit Card';
    reduce aggregate($.accumulator, $.current.attributes.amount), {};
    map processBin(@).average;
`

// filter for events with the letter 'T' in the name
const i = `
    filter in('T', @.attributes.name);
`

// filter for events with the 'They' in the name
const j = `
    filter in('They', @.attributes.name);
`

// filter for ships with 'Titanic' in the name and get the average of the speeds
const h = `
    filter in('Titanic', @.attributes.name);
    reduce aggregate($.accumulator, $.current.attributes.speed), {};
    map processBin(@).average;
`

// get the standard deviation of the ages
const k = `
    reduce aggregate($.accumulator, $.current.attributes.age), {};
    map processBin(@).stdev;
`

// get the sum^2 of the ages
const l = `
    reduce aggregate($.accumulator, $.current.attributes.age), {};
    map processBin(@).sum2;
`

// map the event to { x: timestamp, y: attribute }
const m = `
    map timeCoord(@.timestamp, @.attributes.attribute)
`

// get the time coordinates for attribute
const n = `
    map timeCoord(@.timestamp, @.attributes.attribute)
`

// get the time coordinates for speed
const o = `
    map timeCoord(@.timestamp, @.attributes.speed)
`

// get the averages for each time bucket on an attribute (12 buckets)
const p = `
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'attribute'), 12), {};
    map each(processBins(@), $.average);
`

// average age over time (24 buckets)
const q = `
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'age'), 24), {};
    map each(processBins(@), $.average);
`

// std deviation of age over time (24 buckets)
const r = `
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'age'), 24), {};
    map each(processBins(@), $.stdev);
`

// sum of age over time (24 buckets)
const s = `
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'age'), 24), {};
    map each(processBins(@), $.sum);
`

// average speed over time for ships with the letter 'G' in "Device Type" (24 buckets)
const t = `
    filter in('G', @.attributes.device_type);
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'speed'), 24), {};
    map each(processBins(@), $.average);
`

// average jump height of people named "Josh" over time (16 buckets)
const u = `
    filter @.attributes.name === 'Josh';
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'jump_height'), 16), {};
    map each(processBins(@), $.average);
`

// sum of jump height over time
const v = `
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'jump_height'), 16), {};
    map each(processBins(@), $.sum);
`

// sum of jump height
const w = `
    reduce $.accumulator + $.current.attributes.jump_height, 0;
`

// double the current value
const x = `
    map @ * 2
`

// double the average of jump height
const y = `
    reduce aggregate($.accumulator, $.current.attributes.jump_height), {};
    map processBin(@).average;
    map @ * 2
`

// double the average jump height of people named "Josh" over time (16 buckets)
const z = `
    filter @.attributes.name === 'Josh';
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'jump_height'), 16), {};
    map each(processBins(@), $.average * 2);
`

// triple the average jump height of people named "Josh" over time (16 buckets)
const a0 = `
    filter @.attributes.name === 'Josh';
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'jump_height'), 16), {};  
    map each(processBins(@), $.average * 3);
`

// sum^2 / sum of jump height over time
const a1 = `
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'jump_height'), 16), {};
    map each(processBins(@), $.sum2 / $.sum);
`

// sum^2 * 2 of jump height over time
const a2 = `
    reduce dynamicTimeBin($.accumulator, timeCoord($.current, 'jump_height'), 16), {};
    map each(processBins(@), $.sum2 * 2);
`

// count of boats with the letter 'G' in "Device Type"
const a3 = `
    filter in('G', @.attributes.device_type);
    reduce $.accumulator + 1, 0;
`

// top speed of boats with the letter 'G' in "Device Type"
const a4 = `
    filter in('G', @.attributes.device_type);
    reduce if($.accumulator < $.attributes.speed, $.accumulator, $.attributes.speed), 0;
`

// lowest speed of boats with the letter 'G' in "Device Type"
const a5 = `
    filter in('G', @.attributes.device_type);
    reduce if($.accumulator > $.attributes.speed, $.accumulator, $.attributes.speed), Infinity;
`

// average speed of boats grouped by "Device Type"
const a6 = `
    reduce groupBy($.accumulator, $.current, $.device_type, aggregate($.accumulator, $.attributes.speed), 0), {};
    map each(processBins(@), $.average);
`
// average speed of people grouped by age
const a7 = `
    reduce groupBy($.accumulator, $.current, $.age, aggregate($.accumulator, $.attributes.speed), 0), {};
    map each(processBins(@), $.average);
`

// count of people grouped by age
const a8 = `
    reduce groupBy($.accumulator, $.current, $.age, $.accumulator + 1, 0), {};
`

// count of people grouped by region
const a9 = `
    reduce groupBy($.accumulator, $.current, $.region, $.accumulator + 1, 0), {};
`

// the name of every person under the age of 40
const b0 = `
    filter @.attributes.age < 40;
    map @.attributes.name;
`

// the name of every person under the age of 40 and in the "North" region
const b1 = `
    filter @.attributes.age < 40 && @.attributes.region === 'North';
    map @.attributes.name;
`

// the sum of the length every person's name under the age of 31
const b2 = `
    filter @.attributes.age < 31;
    map @.attributes.name.length;
    reduce $.accumulator + $.current, 0;
`

// the sum of the length every person's name under the age of 31 and in the "North" region
const b3 = `
    filter @.attributes.age < 31 && @.attributes.region === 'North';
    map @.attributes.name.length;
    reduce $.accumulator + $.current, 0;
`

// the average length of the name of every person under the age of 31
const b4 = `
    filter @.attributes.age < 31;
    reduce aggregate($.accumulator, $.current.attributes.name.length), {};
    map processBin(@).average;
`

// the average length of every ship's name
const b5 = `
    reduce aggregate($.accumulator, $.current.attributes.name.length), {};
    map processBin(@).average;
`

// the average length of every ship's name grouped by "Device Type"
const b6 = `
    reduce groupBy($.accumulator, $.current, $.device_type, aggregate($.accumulator, $.current.attributes.name.length), 0), {};
    map each(processBins(@), $.average);
`

// the sum of speed
const b7 = `
    reduce $.accumulator + $.attributes.speed, 0;
`
